==> haskell-tasty-ant-xml-1.1.9-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-ant-xml
version:              1.1.9
visibility:           public
id:                   tasty-ant-xml-1.1.9-E6BF7QngBDO4ARGME0niNg
key:                  tasty-ant-xml-1.1.9-E6BF7QngBDO4ARGME0niNg
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  33b9c97505b6bf50bd7cf322cb742a8c
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.9-E6BF7QngBDO4ARGME0niNg
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    generic-deriving-1.14.6-9CpaKI7sOgC5ilz5rzBe8U ghc-prim-0.9.1
    mtl-2.2.2 stm-2.5.1.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-2nm1gWjYfnlIbZe7wO2Q6V transformers-0.5.6.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-ant-xml-1.1.9-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-ant-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-ant-xml
version:              1.1.9
visibility:           public
id:                   tasty-ant-xml-1.1.9-BzKzX3iVN70AO6VYOKtrj6
key:                  tasty-ant-xml-1.1.9-BzKzX3iVN70AO6VYOKtrj6
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  be192799504372ca8bb31ec7e3d38f7b
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-ant-xml-1.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-ant-xml
hs-libraries:         HStasty-ant-xml-1.1.9-BzKzX3iVN70AO6VYOKtrj6
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    generic-deriving-1.14.6-IdkBRCRyOIuHPRaIPZ6zin ghc-prim-0.9.1
    mtl-2.2.2 stm-2.5.1.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.5-4qs3JVCwJf4LGOgKldJdL2 transformers-0.5.6.2
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
